BasicToken<T> class

Implemented types
Available extensions

Constructors

BasicToken(InjectableValue<T> creator()?)

Properties

creator InjectableValue<T> Function()?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createFallback() InjectableValue<T>?
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
provideAdditional(Factory<Iterable<T>> creator) Provider

Available on Token<ValueCollection<T>>, provided by the ValueCollectionTokenExtension extension

provideOverride(Factory<T> factory) Provider
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited