ProviderMode enum
The mode in which the providers for a WiretapContext are applied. This controls ordering as well as duplication behavior.
Values
- overriding → const ProviderMode
-
Overriding providers are executed before modifying providers and will error on duplicate registrations.
- modifying → const ProviderMode
-
Modifying providers are executed after every other provider type and won't error on multiple duplicate registration.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ProviderMode> - A constant List of the values in this enum, in order of their declaration.